from bs4 import BeautifulSoup as BS
import requests


def get_subunidades():

    link = 'https://sigaa.ufma.br/sigaa/public/docente/busca_docentes.jsf?aba=p-academico'
    subunidades = []

    try:
        page_text = requests.get(link).text
        page = BS(page_text, 'lxml')

        select = page.find(
            'select', {"id":"form:departamento"})
        options = select.find_all('option')
        for option in options[1:]:
            subunidades.append ({"nome": option.text, "codigo": option['value']})
            

    except Exception as e:
        print('erro ao recuperar a subunidade: ', e)

    
    return subunidades

get_subunidades()

# https://sigaa.ufma.br/sigaa/public/departamento/portal.jsf?id=1396&lc=pt_BR
def get_subunidade(codigo):
    link = 'https://sigaa.ufma.br/sigaa/public/departamento/portal.jsf?id='+codigo+'&lc=pt_BR'
    subunidade = {}

    try:
        page_text = requests.get(link).text
        page = BS(page_text, 'lxml')

        subunidade['nome'] = page.find(
            'span', class_='portal-title-1').text.strip()
        info = page.find(
            'div', class_='module variacao-module-02 orgaos-vinculados').find_all('div')
        subunidade['descricao'] = info[1].text.strip()
        info = page.find(
            'div', class_='module variacao-module-02 orgaos-vinculados').find_all('li')
        next_ = info[0].find_all_next(string=True)
        subunidade['chefia'] = next_[1].strip()
        subunidade['telefone'] = next_[5].strip()
        subunidade['endereco_alt'] = next_[9].strip()
    except Exception as e:
        print('erro ao recuperar a subunidade: ', e)

    return subunidade

# https://sigaa.ufma.br/sigaa/public/departamento/professores.jsf?id=1396&lc=pt_BR
def get_docentes(codigo):
    link = 'https://sigaa.ufma.br/sigaa/public/departamento/professores.jsf?id='+codigo
    docentes = []
    try:
        page_text = requests.get(link).text
        page = BS(page_text, 'lxml')
        tables = page.find_all('table', class_="table_lt")
        for tb in tables:
            docente = {}
            rows = tb.find_all('tr')
            cols = rows[1].find_all('td')
            href = cols[0].find("a").get('href')
            siape = href[39:46]
            docente['siape'] = siape
            docente['nome'] = cols[0].get_text().strip()
            docente["codigo_subunidade"] = codigo
            docentes.append(docente)
    except:
        print('erro ao recuperar os docentes!')
    return docentes

# https://sigaa.ufma.br/sigaa/public/departamento/administrativo.jsf?id=1396&lc=pt_BR
def get_administrativo(codigo):
    link = 'https://sigaa.ufma.br/sigaa/public/departamento/administrativo.jsf?id='+codigo
    administrativo = {}

    try:
        page_text = requests.get(link).text
        page = BS(page_text, 'lxml')
        administrativo['data'] = page.find('p', class_='vazio')
    except Exception as e:
        print('erro ao recuperar os administradores: ', e)

    return administrativo


# https://sigaa.ufma.br/sigaa/public/departamento/componentes.jsf?id=1396&lc=pt_BR
def get_disciplinas(codigo):
    link = 'https://sigaa.ufma.br/sigaa/public/departamento/componentes.jsf?id=' + codigo
    disciplinas = {}
    data = []

    try:
        page_text = requests.get(link).text
        page = BS(page_text, 'lxml')
        tables = page.find_all('div', class_='listagem_tabela')
        for tb in tables:
            disciplina = {}
            rows = tb.find_all('tr')
            cols = rows[1].find_all('td')
            disciplina['codigo'] = cols[0].text.strip()
            disciplina['nome'] = cols[1].a.text.strip()
            disciplina['tipo'] = cols[2].text.strip()
            disciplina['ch'] = cols[3].text.strip()
            data.append(disciplina)
    except Exception as e:
        print('erro ao recuperar as disciplinas: ', e)

    disciplinas['data'] = data

    return disciplinas

# https://sigaa.ufma.br/sigaa/public/departamento/extensao.jsf?id=1396&lc=pt_BR
def get_extensoes(codigo):
    link = 'https://sigaa.ufma.br/sigaa/public/departamento/extensao.jsf?id='+codigo
    extensoes = {}

    try:
        page_text = requests.get(link).text
        page = BS(page_text, 'lxml')
        extensoes['data'] = page.find('p', class_='vazio')
    except Exception as e:
        print('erro ao recuperar extensoes: ', e)

    return extensoes


# https://sigaa.ufma.br/sigaa/public/departamento/pesquisa.jsf?id=1396&lc=pt_BR
def get_pesquisas(codigo):
    link = 'https://sigaa.ufma.br/sigaa/public/departamento/pesquisa.jsf?id='+codigo
    pesquisas = {}

    try:
        page_text = requests.get(link).text
        page = BS(page_text, 'lxml')
        pesquisas['data'] = page.find('p', class_='vazio')
    except Exception as e:
        print('erro ao recuperar pesquisas: ', e)

    return pesquisas

# https://sigaa.ufma.br/sigaa/public/departamento/monitoria.jsf?id=1396&lc=pt_BR
def get_monitorias(codigo):
    link = 'https://sigaa.ufma.br/sigaa/public/departamento/monitoria.jsf?id='+codigo
    monitorias = {}

    try:
        page_text = requests.get(link).text
        page = BS(page_text, 'lxml')
        monitorias['data'] = page.find('p', class_='vazio')
    except Exception as e:
        print('erro ao recuperar as monitorias: ', e)
    
    return monitorias


# https://sigaa.ufma.br/sigaa/public/departamento/documentos.jsf?id=1396&lc=pt_BR
def get_documentos(codigo):
    link = 'https://sigaa.ufma.br/sigaa/public/departamento/documentos.jsf?id='+codigo
    documentos = {}

    try:
         page_text = requests.get(link).text
         page = BS(page_text, 'lxml')
         documentos['data'] = page.find('p', class_='vazio')
    except Exception as e:
         print('erro ao recuperar os documentos: ', e)

    return documentos




import requests
import urllib.parse
from unidecode import unidecode
import json
from unicodedata import normalize


from pymarc import JSONReader


from bs4 import BeautifulSoup as BS

def getViewState(r):
    text = r.text
    page = BS(text,'lxml')
    input = page.find('input', id='javax.faces.ViewState')
    return input.get("value")

headers = {
            'Content-Type': 'application/x-www-form-urlencoded',
            'Accept-Language': 'pt-BR,pt;q=0.9,en-US;q=0.8,en;q=0.7,de-DE;q=0.6,de;q=0.5,en-GB;q=0.4'
            }

def get_detail (payload, cookies, id):
    payload["javax.faces.ViewState"]: id
    payload["formBuscaPublica:ClinkView"] = "formBuscaPublica:ClinkView"
    payload["idTitulo"] = "81809"    
    payload["idsBibliotecasAcervoPublicoFormatados"] = "50_39_40_30_49_37_34_32_36_47_860203_42_45_43_48_31_41_38_33_46_44_35"
    payload["apenasSituacaoVisivelUsuarioFinal"] = "true"
    url = "https://sigaa.ufma.br/sigaa/public/biblioteca/buscaPublicaAcervo.jsf"
    try:
        page_response = requests.post(url, data=payload, cookies=cookies)
        page = BS(page_response.text, 'lxml')
        #table = page.find('table', class_='visualizacao')
        print (page)
    except Exception as e:
        print("erro ao recuperar os details acervo: ", e)


def get_acervo(titulo, autor=None, limit=25):
    link = 'https://sigaa.ufma.br/sigaa/public/biblioteca/buscaPublicaAcervo.jsf'

    if not limit:
        limit = 25

    livros = []
    try:
        page_response = requests.get(link)
        page = BS(page_response.text, 'lxml')
        
        #print ("---", limit)
        id = getViewState(page_response);
        cookies = dict(JSESSIONID=page_response.cookies['JSESSIONID'])

        #payload =  { "form":"form", "form:checkAno":"on", "form:idCurso":codigo, "form:lc":"pt_BR", "form:ano":ano, "form:buscar":"Buscar", "javax.faces.ViewState":id}
        payload = {
            "formBuscaPublica": "formBuscaPublica",
            "formBuscaPublica:j_id_jsp_476315297_53": "1",
            "formBuscaPublica:j_id_jsp_476315297_55": str(limit),
            "formBuscaPublica:j_id_jsp_476315297_58": "-1",
            "formBuscaPublica:j_id_jsp_476315297_62": "-1",
            "formBuscaPublica:checkTipoMaterial": "on",
            "formBuscaPublica:j_id_jsp_476315297_66": "16",
            "formBuscaPublica:botaoPesquisarPublicaMulti": "Pesquisar",
            "javax.faces.ViewState": id
        }

        if (titulo):
            titulo = unidecode(titulo)
            titulo = urllib.parse.quote_plus(titulo)
            payload["formBuscaPublica:checkTitulo"] = "on"
            payload["formBuscaPublica:j_id_jsp_476315297_41"] = titulo,

        if (autor):
            autor = unidecode(autor)
            autor = urllib.parse.quote_plus(autor)
            payload["formBuscaPublica:checkAutor"] = "on"
            payload["formBuscaPublica:j_id_jsp_476315297_43"] = autor

          
        url ='https://sigaa.ufma.br/sigaa/public/biblioteca/buscaPublicaAcervo.jsf'
        response = requests.post(url, data=payload, cookies=cookies)

        page = BS(response.text,'lxml')
        div = page.find('div', id="formBuscaPublica:divResultadoPesquisaTitulos")
        table = div.find('table', class_='listagem')
        rowsPar = table.find_all('tr', class_='linhaPar')
        rowsImpar = table.find_all('tr', class_='linhaImpar')
        rows = rowsPar + rowsImpar
        for row in rows:
            cols = row.find_all('td')
            if (len (cols) == 7):
                jssrc = cols[5].find("a").get("onclick")
                q = "'idTitulo':'"
                idi = jssrc.find (q) + len (q)
                idf = jssrc.find ("','", idi) 
                codigo = jssrc[idi:idf]
                
                #livro = extrai_marc_to_json(codigo)
                livro = { "autor" : cols[0].text.strip(),
                        "titulo" : cols[1].text.strip(),
                        "ano" : cols[3].text.strip(),
                        "edicao" : cols[4].text.strip(),
                        "codigo" : codigo,
                        "url_marc" : "https://sigaa.ufma.br/sigaa/public/biblioteca/informacoesMarcTitulo.jsf?idTitulo="+codigo+"&exibirPaginaDadosMarc=true"
                         }
                livros.append (livro)
  
    except Exception as e:
        print("erro ao recuperar o acervo: ", e)
    

    return livros


# tratar os dados no formato marc

def getfl(l,i):
    return l[i] if i < len(l) else ' '

def to_marc_json (ls):
    dic = {}
    print (ls)
    dic["leader"] = ls[0][1]
    dic["fields"] = []
    for t in ls[1:]:
        field = {}
        s = t[0].split()
        if t[1][0] == "$":
            d = {"ind1" : " ", "ind2" : " ", "subfields" : []}
            l =  t[1].split ("$")
            #print (l)
            for sub in l[1:]:
                subf = {}
                subf[sub[0]] = sub[1:].strip()
                #print (subf)
                d["subfields"].append (subf)
                d["ind1"] = getfl(s,1)
                d["ind2"] = getfl (s,2)
            field[s[0]] = d
        else:
            field[s[0]] = t[1].strip()         
        dic["fields"].append (field)

    return (dic) 

def fieldstovalues(fields):
    l = []
    for f in fields:
        l.append(f.value())
    return l

def getfieldValue (r, n, l):
    if r[n]:
        return r[n][l]
    else:
        return ""
def extrai_marc_to_json (idtitulo):
    url = "https://sigaa.ufma.br/sigaa/public/biblioteca/informacoesMarcTitulo.jsf?idTitulo="+idtitulo+"&exibirPaginaDadosMarc=true"
    values = []
    try:
        page_response = requests.get(url)
        page = BS(page_response.text, 'lxml')
        table = page.find('table', class_='tabelaTransparete')
        rows = table.find_all('tr')
        if (len(rows) < 2):
            return None
        for r in rows[1:]:
            cols = r.find_all('td')
            c0 = cols[0].text.strip().replace ("\t","").replace("\r\n","").replace("&nbsp","")
            c1 = cols[1].text.strip().replace ("\t","").replace("\r\n","").replace("&nbsp","")
            values.append ((c0,c1))
        
    except Exception as e:
        print("erro ao extrair : ", e)

    dic = to_marc_json(values)
    jsr = json.dumps(dic)
    reader = JSONReader (jsr)

    for r in reader:
        '''
        if (r.isbn()):
            urlGoogle = "https://www.googleapis.com/books/v1/volumes?q="+r.isbn()
            google_book = requests.get(urlGoogle).json()
        else:
            google_book = {}
        '''  

        return {"title" : r.title(), "author" : r.author(), "isbn" : r.isbn(),
                "position" :  r['090']['a'] + " " + r['090']['b'], "id" : idtitulo,
                "publocation" : getfieldValue(r,'260','a'), "pubyear" : r.pubyear(), 
                "publisher" : r.publisher(), "edition" : getfieldValue(r,'250','a'),
                "subjects" : fieldstovalues (r.subjects()) }




import requests
import json
from bs4 import BeautifulSoup as BS


def get_docente(siape):
        link = 'https://sigaa.ufma.br/sigaa/public/docente/portal.jsf?siape='+siape
        docente = {}

        try:
                page_text = requests.get(link).text

                
                page = BS(page_text, 'lxml')

                info = page.find_all('div', class_='secao-pagina')


                docente['nome'] = page.find('p', class_='span outstanding-title').text.strip()
                docente['subunidade'] = page.find('span', class_='outstanding-subtitle').text.strip()
                docente['descricao'] = info[0].text.split('\n')[-2].strip()
                docente['formacao'] = info[1].text.split('\n')[-2].strip()
                docente['areas_interesse'] = info[2].text.split('\n')[-2].strip()
                docente['lattes'] = page.find(
                    'a', id='endereco-lattes').get('href').strip()
                docente['email'] = page.find_all('span')[-5].text.strip()
                docente['telefone'] = page.find_all(
                    'span')[-6].text.strip()

                imgurl = "https://sigaa.ufma.br/" + page.find("div", class_="span2").find("img").get("src")
                docente["urlimg"] = imgurl
                
        except Exception as e:
                print('erro ao recuperar o docente: ', e)

        return docente


# https://sigaa.ufma.br/sigaa/public/docente/disciplinas.jsf?siape=407686&lc=pt_BR

def get_turmas(siape):
        link = 'https://sigaa.ufma.br/sigaa/public/docente/disciplinas.jsf?siape='+siape
        turmas = {}
        data = []

        try:
                page_text = requests.get(link).text
                page = BS(page_text, 'lxml')

                tables = page.find_all('div', class_='listagem_tabela')

                for tb in tables:
                        rows = tb.find_all('tr')
                        for i in range(len(rows)-1):
                                disciplina = {}
                                if i%2 != 0:
                                        cols = rows[i].find_all('td')
                                        disciplina['codigo'] = cols[0].text.strip()
                                        disciplina['nome'] = cols[1].a.text.strip()
                                        disciplina['ano'] = cols[2].text.strip()
                                        disciplina['ch'] = cols[3].text.strip()
                                        data.append(disciplina)

                turmas['data'] = data
        except Exception as e:
                print("erro ao recuperar turmas: ", e)

        return turmas  


# https://sigaa.ufma.br/sigaa/public/docente/pesquisa.jsf?siape=407686&lc=pt_BR
def get_projetos(siape):
        link = 'https://sigaa.ufma.br/sigaa/public/docente/pesquisa.jsf?siape='+siape
        projetos = {}
        data = []

        try:
                page_text = requests.get(link).text
                page = BS(page_text, 'lxml')

                tables = page.find_all('div', 'listagem_tabela')

                for tb in tables:
                        rows = tb.find_all('tr')[1:]
                        for row in rows:
                                projeto = {}
                                cols = row.find_all('td')
                                projeto['codigo'] = cols[0].text.strip()
                                projeto['nome'] = cols[1].text.strip()
                                projeto['area'] = cols[2].text.strip()
                                projeto['ano'] = cols[3].text.strip()
                                data.append(projeto)
                projetos['data'] = data
        
        except Exception as e:
                print('erro ao recuperar os projetos: ', e)
        
        return projetos

#https://sigaa.ufma.br/sigaa/public/docente/producao.jsf?siape=1763530&lc=pt_BR
def get_producao (siape):
        link = 'https://sigaa.ufma.br/sigaa/public/docente/producao.jsf?siape='+siape
        producao = {}

        try:
                page_text = requests.get(link).text
                page = BS(page_text, 'lxml')
                tables = page.find_all('div', 'listagem_tabela')
                artigos = []
                publicacoes = []
                capitulos= []
                tecnologias = []
                tccs = []

                for index in range(len(tables)):
                        rows = tables[index].find_all('tr')
                        if rows[0].find('td').text.strip()[:7] == 'Artigos': #Artigos
                                
                                for row in rows[1:]:
                                        cols = row.find('td')
                                        artigo = {}
                                        artigo['autor'] = page.find('h4', class_='span outstanding-title').text.strip()
                                        artigo['tema'] = cols.b.text.strip()
                                        artigo['ano'] = cols.text.split(',')[0].strip()
                                        artigo['issn'] = cols.text.split(',')[-1].strip()[6:]
                                        artigos.append(artigo)

                        if rows[0].find('td').text.strip()[:7] == 'Publica': #Publicações em Eventos
                                
                                for row in rows[1:]:
                                        cols = row.find('td')
                                        publicacao = {}
                                        publicacao['tema'] = cols.b.text.strip()
                                        info = cols.text.replace(publicacao['tema'],'#')
                                        publicacao['autores'] = info.split('#')[0].split(',')[1:-1]
                                        publicacao['autores'][0] = publicacao['autores'][0].strip()
                                        publicacao['ano'] = cols.text[:4]
                                        publicacao['evento'] = info.split('#')[1].split(',')[1].strip()
                                        publicacoes.append(publicacao)
                        
                        if rows[0].find('td').text.strip()[:3] == 'Cap':

                                for row in rows[1:]:
                                        cols = row.find('td')
                                        capitulo = {}
                                        capitulo['titulo'] = cols.b.text.strip()
                                        info = cols.text.replace(capitulo['titulo'],'#')
                                        capitulo['livro'] = info.split('#')[1].split(',')[1].strip()
                                        capitulo['autores'] = info.strip().split('#')[1].split(',')[2:]
                                        capitulo['ano']= cols.text[:4]
                                        capitulos.append(capitulo)
                
                        if rows[0].find('td').text.strip()[:5] == 'Produ':

                                for row in rows[1:]:
                                        cols = row.find('td')
                                        producao = {}
                                        producao['titulo'] = cols.b.text.strip()
                                        info = cols.text.replace(producao['titulo'],'#')
                                        producao['autores'] = info.strip().split('#')[1].split(',')[1:]
                                        producao['ano']= cols.text[:4]
                                        tecnologias.append(producao)
                        
                        if rows[0].find('td').text.strip()[:8] == 'Trabalho':

                                for row in rows[1:]:
                                        cols = row.find('td')
                                        tcc = {}
                                        tcc['titulo'] = cols.b.text.strip()
                                        info = cols.text.replace(tcc['titulo'],'#')
                                        tcc['autor'] = info.split('#')[1].split(',')[1].strip()
                                        tcc['data'] = info.split('#')[1].split(',')[2].strip()
                                        print(tcc)
                                        tccs.append(tcc)
                
                producao['artigos'] = artigos
                producao['publicacoes'] = publicacoes
                producao['capitulos_livros'] = capitulos
                producao['producao_tecnologica'] = tecnologias
                producao['orientandos'] = tccs
                                        
                
        except Exception as e:
                print('erro ao recuperar as produções: ', e)

        return producao
                        

#print (get_docente ("1763530"))


import requests
from bs4 import BeautifulSoup as BS


def getViewState(r):
    text = r.text
    page = BS(text, 'lxml')
    input = page.find('input', id='javax.faces.ViewState')
    return input.get("value")


def col2curso(cols):
    nome = cols[0].text.strip()
    sede = cols[1].text.strip()
    modalidade = cols[2].text.strip()
    coordenador = cols[3].text.strip()
    url = cols[4].find("a").get('href')
    i1, i2 = url.find("id=")+3, url.find("&lc")
    codigo = url[i1:i2]
    return {"nome": nome, "municipio": sede,  "codigo": codigo, "modalidade": modalidade, "coordenador":coordenador}


def get_cursos():
    link = 'https://sigaa.ufma.br/sigaa/public/curso/lista.jsf' 
    try:
        page_response = requests.get(link)
        page = BS(page_response.text, 'lxml')
        id = getViewState(page_response)
        cookies = dict(JSESSIONID=page_response.cookies['JSESSIONID'])
        payload = {
            "form": "form",  "nivel": "G", "form:checkModalidade": "on",
            "form:modalidadeDeEnsino": 1, "form:lc": "pt_BR",
            "form:consultarCursos": "Consultar", "javax.faces.ViewState": id
        }
        url ='https://sigaa.ufma.br/sigaa/public/curso/lista.jsf'
        response = requests.post(url, data=payload, cookies=cookies)
        page = BS(response.text, 'lxml')
        table = page.find('table', class_='listagem')
        rowsPar = table.find_all('tr', class_='linhaPar')
        rowsImpar = table.find_all('tr', class_='linhaImpar')
        cursos = []
        for r in rowsPar:
            cols = r.find_all('td')
            cursos.append(col2curso(cols))

        for r in rowsImpar:
            cols = r.find_all('td')
            cursos.append(col2curso(cols))

    except Exception as e:
        print("erro ao recuperar as monografias: ", e)

    return cursos


def get_monografias(codigo, ano):
    link = 'https://sigaa.ufma.br/sigaa/public/curso/monografias_curso.jsf?lc=pt_BR&id=' + codigo
    data = []
    monografias = {}
    try:
        page_response = requests.get(link)
        page = BS(page_response.text, 'lxml')
        id = getViewState(page_response)
        cookies = dict(JSESSIONID=page_response.cookies['JSESSIONID'])
        payload = {
            "form": "form", "form:checkAno": "on", "form:idCurso": codigo,
            "form:lc": "pt_BR", "form:ano": ano, "form:buscar": "Buscar",
            "javax.faces.ViewState": id
        }
        url = 'https://sigaa.ufma.br/sigaa/public/curso/monografias_curso.jsf'
        response = requests.post(url, data=payload, cookies=cookies)
        page = BS(response.text, 'lxml')
        table = page.find('table', class_="table_lt")
        rows = table.find_all('tr')[1:]
        for index in range(len(rows)-1):
            monografia = {}
            cols = rows[index].find_all('td')
            if len(cols) == 6:
                monografia['discente'] = cols[2].text.strip()
                monografia['orientador'] = cols[3].text.strip()
                monografia['titulo']= rows[index+1].text.strip()[7:].strip()
                data.append(monografia)
    except Exception as e:
        print("erro ao recuperar as monografias: ", e)
    monografias['data'] = data
    return monografias


def get_discentes_ativos(codigo):
    link = 'https://sigaa.ufma.br/sigaa/public/curso/alunos_curso.jsf?lc=pt_BR&id=' + codigo
    discentes = {}
    data = []
    try:
        page_text = requests.get(link).text
        page = BS(page_text, 'lxml')
        table = page.find('table', class_='table_lt')
        rows = table.find_all('tr')[1:]
        for row in rows[:-1]:
            discente = {}
            cols = row.find_all('td')
            discente['nome_curso'] = page.find_all('span', class_='portal-title-1')[0].text.strip()
            discente['codigo_curso'] = codigo
            discente['matricula'] = cols[0].text.strip()
            discente['nome'] = cols[1].text.strip()
            data.append(discente)

    except Exception as e:
        print('erro ao recuperar os alunos : ', e)
    discentes['data'] = data
    return discentes


def get_turmas(codigo, ano, periodo):
    link = 'https://sigaa.ufma.br/sigaa/public/curso/turma_curso.jsf?lc=pt_BR&id=' + codigo
    data = []
    turmas = {}
    try:
        page_response = requests.get(link)
        page = BS(page_response.text, 'lxml')
        id = getViewState(page_response);
        cookies = dict(JSESSIONID=page_response.cookies['JSESSIONID'])
        payload = {
            "form": "form", "form:inputAno": ano, "form:id": codigo,
            "form:lc": "pt_BR", "form:buscarTurmas": "Buscar", "javax.faces.ViewState": id,
            "form:inputPeriodo": periodo
        }
        url = 'https://sigaa.ufma.br/sigaa/public/curso/turma_curso.jsf?lc=pt_BR&id=' + codigo
        response = requests.post(url, data=payload, cookies=cookies)
        page = BS(response.text, 'lxml')
        divs = page.find_all('div', class_='listagem_tabela')
        n = len (divs)
        for div in divs[:n-1]:
            nome_curso = div.find ('div', id='group_lt').find("a").get_text().strip()
            tbody = div.find ('tbody')
            rows = tbody.find_all('tr')
            for row in rows:
                turma = {}
                turma["nome_curso"] = nome_curso
                turma["vagas"] = row.find ('td', class_='colVagas').get_text().strip()
                turma["horario"] = row.find ('td', class_='horario').get_text().strip()
                turma["docente"] = row.find ('td', class_='nome').get_text().strip().replace('\t', '').replace('\n', '')
                turma["numturma"] = row.find ('td', align='center').get_text().strip()
                data.append(turma)
    except Exception as e:
        print("erro ao recuperar as turmas: ", e)
    turmas['data'] = data
    return turmas



import requests
import json
from bs4 import BeautifulSoup as BS


# https://sigaa.ufma.br/sigaa/public/centro/portal.jsf?lc=pt_BR&id=966
def get_unidade(codigo):
    link = 'https://sigaa.ufma.br/sigaa/public/centro/portal.jsf?id='+codigo+'&lc=pt_BR'
    unidade = {}

    try:
        page_text = requests.get(link).text
        page = BS(page_text, 'lxml')
        titulo = page.find('span', class_='portal-title corto').get_text()
        div = page.find(
            'div', class_='module variacao-module-02 orgaos-vinculados')
        info_centro = div.find_all('li')

        unidade['nome'] = titulo.strip()
        unidade['diretor'] = info_centro[1].get_text().strip()
        unidade['telefone'] = info_centro[3].get_text().strip()
        unidade['end_alt'] = info_centro[5].get_text().strip()

    except:
        print('erro ao recuperar unidade!')
    return unidade

# https://sigaa.ufma.br/sigaa/public/centro/lista_departamentos.jsf?id=966&lc=pt_BR
def get_subunidades(codigo):
    link = "https://sigaa.ufma.br/sigaa/public/centro/lista_departamentos.jsf?id=" + \
        codigo+"&lc=pt_BR"
    subunidades = []

    try:
        page_text = requests.get(link).text
        page = BS(page_text, 'lxml')
        table = page.find('table', class_="table_lt")
        rows = table.find_all('tr')
        for row in rows[1:]:
            subunidade = {}
            cols = row.find_all('td')
            href = cols[0].find("a").get('href')
            pos = href.find("id=")
            codigo = href[pos+3:]
            subunidade['codigo'] = codigo
            subunidade['nome'] = cols[0].get_text().strip()
            subunidades.append(subunidade)

    except:
        print('erro ao recuperar a subunidade!')
    return subunidades

# https://sigaa.ufma.br/sigaa/public/centro/bases_pesquisa.jsf?id=966&lc=pt_BR
def get_grupos_pesquisa(codigo):
    link = 'https://sigaa.ufma.br/sigaa/public/centro/bases_pesquisa.jsf?id='+codigo+'&lc=pt_BR'
    grupo_de_pesquisas = []

    try:
        page_text = requests.get(link).text
        page = BS(page_text, 'lxml')
        conteudo = page.find('table', class_='table_lt')
        rows = conteudo.find_all('tr')[1:]

        for row in rows:
            pesquisa = {}
            cols = row.find_all('td')
            pesquisa['tema'] = cols[0].get_text().strip()
            pesquisa['pesquisador'] = cols[1].get_text().strip()
            pesquisa['href'] = 'https://sigaa.ufma.br' + \
                cols[1].find('a').get('href')
            grupo_de_pesquisas.append(pesquisa)

    except:
        print('erro ao recuperar as bases de pesquisas!')
    return grupo_de_pesquisas


# https://sigaa.ufma.br/sigaa/public/centro/lista_cursos.jsf?id=966&lc=pt_BR
# aqui tem os codigos do curso, talvez tenha que usar https://sigaa.ufma.br/sigaa/public/curso/lista.jsf
def get_cursos_graduacao(codigo):
    link = 'https://sigaa.ufma.br/sigaa/public/centro/lista_cursos.jsf?id='+codigo+'&lc=pt_BR'
    cursos = []
    data = {}
    page_text = requests.get(link).text
    page = BS(page_text, 'lxml')
    conteudo = page.find('table', class_='table_lt')
    rows = conteudo.find_all('tr')[1:]

    try:
        for row in rows:
            curso = {}
            cols = row.find_all('td')
            curso['nome'] = cols[0].get_text().strip()
            curso['municipio'] = cols[1].get_text().strip()
            curso['modalidade'] = cols[2].get_text().strip()
            curso['coordenador'] = cols[3].get_text().strip()
            cursos.append(curso)
    except:
        print('erro ao recuperar os cursos de graduação!')
    
    data['data'] = cursos
    return data

# https://sigaa.ufma.br/sigaa/public/centro/lista_programas.jsf?id=966&lc=pt_BR

def get_cursos_pos(codigo):
    link = 'https://sigaa.ufma.br/sigaa/public/centro/lista_programas.jsf?id='+codigo+'&lc=pt_BR'
    cursos_pos = []

    page_text = requests.get(link).text
    page = BS(page_text, 'lxml')
    conteudo = page.find('table', class_='table_lt')
    rows = conteudo.find_all('tr')[1:]
    
    try:
        for row in rows:
            curso = {}
            curso['programa'] = row.find('a').get_text().strip()
            href = row.find('a').get('href')
            pos = href.find('idPrograma=')
            codigo = href[pos+11:]
            curso['id'] = codigo
            curso['href'] = 'https://sigaa.ufma.br/sigaa/public/programa/apresentacao_stricto.jsf?lc=pt_BR&idPrograma='+codigo
            cursos_pos.append(curso)
    except:
        print('erro ao recuperar os cursos de pos-graduação!')

    return cursos_pos

def get_documentos(codigo):
        pass